# Copyright 2023 Baidu, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file
# except in compliance with the License. You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software distributed under the
# License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
# either express or implied. See the License for the specific language governing permissions
# and limitations under the License.
"""
This module provide doc hub.
"""

from pymochow.ai.dochub.dochub import (
    DocumentHub,
    DocumentHubEnv
)
from pymochow.ai.dochub.local_dochub import LocalDocumentHub
from pymochow.ai.dochub.bos_dochub import BosDocumentHub

__all__ = [
    "DocumentHub",
    "DocumentHubEnv",
    "LocalDocumentHub",
    "BosDocumentHub"
]
